@@ -3,12 +3,12 @@
     <name>defaultlook</name>
     <message>
         <location filename="defaultlook.ui" line="20"/>
-        <location filename="defaultlook.cpp" line="55"/>
-        <location filename="defaultlook.cpp" line="467"/>
-        <location filename="defaultlook.cpp" line="474"/>
-        <location filename="defaultlook.cpp" line="491"/>
-        <location filename="defaultlook.cpp" line="502"/>
-        <location filename="defaultlook.cpp" line="512"/>
+        <location filename="defaultlook.cpp" line="52"/>
+        <location filename="defaultlook.cpp" line="464"/>
+        <location filename="defaultlook.cpp" line="471"/>
+        <location filename="defaultlook.cpp" line="488"/>
+        <location filename="defaultlook.cpp" line="499"/>
+        <location filename="defaultlook.cpp" line="509"/>
         <source>MX Tweak</source>
         <translation>MX Tweak</translation>
     </message>
@@ -104,318 +104,287 @@
         <translation>Leiste senkrecht anzeigen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="365"/>
+        <location filename="defaultlook.ui" line="359"/>
         <source>Bottom</source>
         <translation>Unten</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="370"/>
+        <location filename="defaultlook.ui" line="364"/>
         <source>Top</source>
         <translation>Oben</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="378"/>
+        <location filename="defaultlook.ui" line="372"/>
         <source>Display panel horizontally</source>
         <translation>Leiste waagerecht anzeigen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="398"/>
+        <location filename="defaultlook.ui" line="386"/>
         <source>Left</source>
         <translation>Links</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="403"/>
+        <location filename="defaultlook.ui" line="391"/>
         <source>Right</source>
         <translation>Rechts</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="411"/>
+        <location filename="defaultlook.ui" line="399"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;wirksam für ALLE Leisten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="431"/>
+        <location filename="defaultlook.ui" line="419"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fensterknöpfe&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="446"/>
-        <location filename="defaultlook.ui" line="549"/>
-        <location filename="defaultlook.ui" line="741"/>
-        <location filename="defaultlook.ui" line="860"/>
-        <location filename="defaultlook.ui" line="902"/>
+        <location filename="defaultlook.ui" line="434"/>
+        <location filename="defaultlook.ui" line="537"/>
+        <location filename="defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="826"/>
+        <location filename="defaultlook.ui" line="868"/>
         <source>Apply</source>
         <translation>Anwenden</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="469"/>
+        <location filename="defaultlook.ui" line="457"/>
         <source>Theme</source>
         <translation>Thema</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="483"/>
+        <location filename="defaultlook.ui" line="471"/>
         <source>Theme Options</source>
         <translation>Themenoptionen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="513"/>
+        <location filename="defaultlook.ui" line="501"/>
         <source>Fix some website fields when using dark theme</source>
         <translation>Einige Webseiten-Felder für das Farbschema &quot;dunkel&quot; korrigieren</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="516"/>
+        <location filename="defaultlook.ui" line="504"/>
         <source>Firefox dark theme tweak</source>
         <translation>Dunkel angepasstes Firefox-Farbschema</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="523"/>
+        <location filename="defaultlook.ui" line="511"/>
         <source>Fix HexChat input box in dark theme</source>
         <translation>HexChat Eingabefeld in dunklem Thema reparieren</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="575"/>
+        <location filename="defaultlook.ui" line="563"/>
         <source>Undo</source>
         <translation>Rückgängig</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="582"/>
+        <location filename="defaultlook.ui" line="570"/>
         <source>Preview</source>
         <translation>Vorschau</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="589"/>
-        <source>Remove User Theme Sets</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="600"/>
-        <source>Save Current Settings as a Theme Set</source>
-        <translation>Einstellungen als Theme Set speichern</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="614"/>
-        <location filename="defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="580"/>
+        <location filename="defaultlook.ui" line="673"/>
         <source>Compositor</source>
         <translation>Compositor</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="635"/>
+        <location filename="defaultlook.ui" line="601"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Einstellungen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="638"/>
+        <location filename="defaultlook.ui" line="604"/>
         <source>Xfwm Settings</source>
         <translation>Xfwm-Einstellungen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="662"/>
+        <location filename="defaultlook.ui" line="628"/>
         <source>None</source>
         <translation>Nichts</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="667"/>
+        <location filename="defaultlook.ui" line="633"/>
         <source>Xfwm (Xfce) Compositor</source>
         <translation>Xfwm (Xfce) Compositor</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="672"/>
+        <location filename="defaultlook.ui" line="638"/>
         <source>Compton </source>
         <translation>Compton </translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="680"/>
+        <location filename="defaultlook.ui" line="646"/>
         <source>Edit compton.conf directly in text editor</source>
         <translation>Bearbeite compton.conf direkt im Texteditor</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="683"/>
+        <location filename="defaultlook.ui" line="649"/>
         <source>Edit compton.conf</source>
         <translation>Bearbeite compton.conf</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="714"/>
+        <location filename="defaultlook.ui" line="680"/>
         <source>Transparency and shadow options</source>
         <translation>Transparenz- und Schattenoptionen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="721"/>
+        <location filename="defaultlook.ui" line="687"/>
         <source>Launch compton-conf configuration tool</source>
         <translation>Starte compton-conf Konfigurationswerkzeug</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="724"/>
+        <location filename="defaultlook.ui" line="690"/>
         <source>Compton settings</source>
         <translation>Compton-Einstellungen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="777"/>
+        <location filename="defaultlook.ui" line="743"/>
         <source>Config Options</source>
         <translation>Konfigurationsoptionen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="785"/>
+        <location filename="defaultlook.ui" line="751"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
         <translation>Lightdm (Login Bildschirm) auf die Systemvoreinstellung zurücksetzen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="792"/>
+        <location filename="defaultlook.ui" line="758"/>
         <source>Reset Thunar custom right-click actions to system defaults</source>
         <translation>Benutzerdefinierten Aktionen in Thunar auf die Systemvoreinstellungen zurücksetzen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="799"/>
+        <location filename="defaultlook.ui" line="765"/>
         <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
         <translation>Intel Treiber anstelle des voreingestellten &quot;modsetting&quot; Treibers benutzen (Neustart erforderlich)</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="806"/>
+        <location filename="defaultlook.ui" line="772"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-intel.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="813"/>
+        <location filename="defaultlook.ui" line="779"/>
         <source>Use tearfree amdgpu option</source>
         <translation>Option &quot;Tearfree&quot; des AMDGPU-Treibers benutzen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="820"/>
+        <location filename="defaultlook.ui" line="786"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
         <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-amd.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="827"/>
+        <location filename="defaultlook.ui" line="793"/>
         <source>Use tearfree radeon driver option</source>
         <translation>Option &quot;Tearfree&quot; des Radeon-Treibers benutzen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="834"/>
+        <location filename="defaultlook.ui" line="800"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
         <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-radeon.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="874"/>
+        <location filename="defaultlook.ui" line="840"/>
         <source>Other</source>
         <translation>Anderes</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="882"/>
+        <location filename="defaultlook.ui" line="848"/>
         <source>Enable single-click on desktop</source>
         <translation>Einfach-Klick auf dem Desktop aktivieren</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="889"/>
+        <location filename="defaultlook.ui" line="855"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Einfach-Klick im Thunar Dateimanager aktivieren</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="926"/>
+        <location filename="defaultlook.ui" line="892"/>
         <source>Show systray (notification area) frame</source>
         <translation>Zeige Rahmen um das Benachrichtigungsfeld (Systray)</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="933"/>
+        <location filename="defaultlook.ui" line="899"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Zeige Fenster von allen Arbeitsflächen in der Leiste</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="940"/>
+        <location filename="defaultlook.ui" line="906"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Aktiviere Einhängen von internen Laufwerken durch Benutzer ohne root-Rechte</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="947"/>
+        <location filename="defaultlook.ui" line="913"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation>Verkürzung langer Dateinamen auf dem Desktop abschalten</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="954"/>
+        <location filename="defaultlook.ui" line="920"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>Ruhezustand im Log-Out Menü zulassen</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="961"/>
+        <location filename="defaultlook.ui" line="927"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>Hinweis: Für den Ruhezustand wird SWAP &gt;= RAM benötigt.</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="466"/>
+        <location filename="defaultlook.cpp" line="463"/>
         <source>About MX Tweak</source>
         <translation>Über MX Tweak</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="467"/>
+        <location filename="defaultlook.cpp" line="464"/>
         <source>Version: </source>
         <translation>Version:</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="468"/>
+        <location filename="defaultlook.cpp" line="465"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation>Anwendung für schnelle Änderungen und Anpassungen an den Voreinstellungen des UI-Themas</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="470"/>
+        <location filename="defaultlook.cpp" line="467"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
+        <location filename="defaultlook.cpp" line="468"/>
         <location filename="defaultlook.cpp" line="471"/>
-        <location filename="defaultlook.cpp" line="474"/>
         <source>License</source>
         <translation>Lizenz</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="472"/>
+        <location filename="defaultlook.cpp" line="469"/>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="503"/>
+        <location filename="defaultlook.cpp" line="500"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>Fertig! Die Änderungen werden nach einem Neustart von Firefox wirksam.</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="513"/>
+        <location filename="defaultlook.cpp" line="510"/>
         <source>This app is Xfce-only</source>
         <translation>Dieses Programm funktioniert nur mit Xfce</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="655"/>
+        <location filename="defaultlook.cpp" line="652"/>
         <source>Panel settings</source>
         <translation>Leisten-Einstellungen</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="656"/>
+        <location filename="defaultlook.cpp" line="653"/>
         <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
         <translation>Die aktuellen Leisten-Einstellungen wurden im versteckten Ordner .restore im Home-Verzeichnis gesichert. (~/.restore/)</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="1073"/>
+        <location filename="defaultlook.cpp" line="1070"/>
         <source>Choose a theme set</source>
         <translation>Wählen Sie ein Thema</translation>
     </message>
 </context>
-<context>
-    <name>remove_user_theme_set</name>
-    <message>
-        <location filename="remove_user_theme_set.ui" line="14"/>
-        <source>Remove User Theme Set</source>
-        <translation>Theme Set entfernen</translation>
-    </message>
-</context>
-<context>
-    <name>theming_to_tweak</name>
-    <message>
-        <location filename="theming_to_tweak.ui" line="14"/>
-        <source>Dialog</source>
-        <translation>Dialog</translation>
-    </message>
-    <message>
-        <location filename="theming_to_tweak.ui" line="20"/>
-        <source>Enter name for new theme set</source>
-        <translation>Namen für das neue Theme Set eingeben</translation>
-    </message>
-</context>
 <context>
     <name>window_buttons</name>
     <message>
